#include <klocale.h>

void frmPlaylist::init()
{
	setCaption(i18n("Playlist's settings"));
	grpPlaylist->setTitle(i18n("Name") + "/" + i18n("Description"));
	chkDest->setText(i18n("set as destination"));
	pshCancel->setText(i18n("Cancel"));

//	QToolTip::add(chkDest, i18n("Use Shift+C/S to copy/send track(s)"));
}

void frmPlaylist::acceptPlaylist()
{
	ok = true;
	hide();
}

void frmPlaylist::rejectPlaylist()
{
	ok = false;
	hide();
}
